pub struct BiDi;Expand description
maplibre/maplibre-native#4add9ea original name: BiDi
Implementations
Sourceimpl BiDi
impl BiDi
Sourcepub fn process_text(
&self,
input: &U16String,
line_break_points: BTreeSet<usize>,
) -> Vec<U16String>
pub fn process_text( &self, input: &U16String, line_break_points: BTreeSet<usize>, ) -> Vec<U16String>
Given text in logical ordering and a set of line break points, return a set of lines in visual order with bidi and line breaking applied maplibre/maplibre-native#4add9ea original name: processText