pub struct PlacedSymbol {Show 15 fields
pub anchor_point: Point2D<f64, TileSpace>,
pub segment: usize,
pub lower_size: f64,
pub upper_size: f64,
pub line_offset: [f64; 2],
pub writing_modes: WritingModeType,
pub line: GeometryCoordinates,
pub tile_distances: Vec<f64>,
pub glyph_offsets: Vec<f64>,
pub hidden: bool,
pub vertex_start_index: usize,
pub cross_tile_id: u32,
pub placed_orientation: Option<TextWritingModeType>,
pub angle: f64,
pub placed_icon_index: Option<usize>,
}Expand description
maplibre/maplibre-native#4add9ea original name: PlacedSymbol
Fields
anchor_point: Point2D<f64, TileSpace>segment: usizelower_size: f64upper_size: f64line_offset: [f64; 2]writing_modes: WritingModeTypeline: GeometryCoordinatestile_distances: Vec<f64>glyph_offsets: Vec<f64>vertex_start_index: usizecross_tile_id: u32The crossTileID is only filled/used on the foreground for variable text anchors
placed_orientation: Option<TextWritingModeType>The placedOrientation is only used when symbol layer’s property is set to support placement for orientation variants.
angle: f64placed_icon_index: Option<usize>Reference to placed icon, only applicable for text symbols.