Struct TaggedString

pub struct TaggedString {
    pub styled_text: (U16String, Vec<u8>),
    pub sections: Vec<SectionOptions>,
    pub supports_vertical_writing_mode: Option<bool>,
    pub image_section_id: u16,
}
A TaggedString is the shaping-code counterpart of the Formatted type Whereas Formatted matches the logical structure of a ‘format’ expression, a TaggedString represents the same data at a per-character level so that character-rearranging operations (e.g. BiDi) preserve formatting. Text is represented as:

  • A string of characters
  • A matching array of indices, pointing to:
  • An array of SectionsOptions, representing the evaluated formatting options of the original sections.

Once the guts of a TaggedString have been re-arranged by BiDi, you can iterate over the contents in order, using getCharCodeAt and getSection to get the formatting options for each character in turn. maplibre/maplibre-native#4add9ea original name: TaggedString

Fields

styled_text: (U16String, Vec<u8>)sections: Vec<SectionOptions>supports_vertical_writing_mode: Option<bool>image_section_id: u16

Implementations

Source

impl TaggedString

const WHITESPACE_CHARS: &'static [u16]

pub fn new_from_raw(text_: U16String, options: SectionOptions) -> Self

maplibre/maplibre-native#4add9ea original name: new_from_raw

pub fn new( styled_text: (U16String, Vec<u8>), sections_: Vec<SectionOptions>, ) -> Self

maplibre/maplibre-native#4add9ea original name: new

pub fn length(&self) -> usize

maplibre/maplibre-native#4add9ea original name: length

pub fn section_count(&self) -> usize

maplibre/maplibre-native#4add9ea original name: sectionCount

pub fn empty(&self) -> bool

maplibre/maplibre-native#4add9ea original name: empty

pub fn get_section(&self, index: usize) -> &SectionOptions

maplibre/maplibre-native#4add9ea original name: getSection

pub fn get_char_code_at(&self, index: usize) -> u16

maplibre/maplibre-native#4add9ea original name: getCharCodeAt

pub fn raw_text(&self) -> &U16String

maplibre/maplibre-native#4add9ea original name: rawText

pub fn get_styled_text(&self) -> &(U16String, Vec<u8>)

maplibre/maplibre-native#4add9ea original name: getStyledText

pub fn add_text_section( &mut self, section_text: &U16String, scale: f64, font_stack: Vec<String>, text_color: Option<Color>, )

maplibre/maplibre-native#4add9ea original name: addTextSection

pub fn add_image_section(&mut self, image_id: String)

maplibre/maplibre-native#4add9ea original name: addImageSection

pub fn section_at(&self, index: usize) -> &SectionOptions

maplibre/maplibre-native#4add9ea original name: sectionAt

pub fn get_sections(&self) -> &Vec<SectionOptions>

maplibre/maplibre-native#4add9ea original name: getSections

pub fn get_section_index(&self, character_index: usize) -> u8

maplibre/maplibre-native#4add9ea original name: getSectionIndex

pub fn get_max_scale(&self) -> f64

maplibre/maplibre-native#4add9ea original name: getMaxScale

pub fn trim(&mut self)

maplibre/maplibre-native#4add9ea original name: trim

pub fn verticalize_punctuation(&mut self)

maplibre/maplibre-native#4add9ea original name: verticalizePunctuation

pub fn allows_vertical_writing_mode(&mut self) -> bool

maplibre/maplibre-native#4add9ea original name: allowsVerticalWritingMode

Source

impl TaggedString

fn get_next_image_section_char_code(&mut self) -> Option<u16>

maplibre/maplibre-native#4add9ea original name: getNextImageSectionCharCode