Struct ViewState

pub struct ViewState {
    zoom: ChangeObserver<Zoom>,
    camera: ChangeObserver<Camera>,
    perspective: Perspective,
    width: f64,
    height: f64,
    edge_insets: EdgeInsets,
}

Fields

zoom: ChangeObserver<Zoom>camera: ChangeObserver<Camera>perspective: Perspectivewidth: f64height: f64edge_insets: EdgeInsets

Implementations

Source

impl ViewState

pub fn new<F: Into<Rad<f64>>, P: Into<Deg<f64>>>( window_size: PhysicalSize, position: WorldCoords, zoom: Zoom, pitch: P, fovy: F, ) -> Self

pub fn set_edge_insets(&mut self, edge_insets: EdgeInsets)

pub fn edge_insets(&self) -> &EdgeInsets

pub fn resize(&mut self, size: LogicalSize)

pub fn create_view_region( &self, visible_level: ZoomLevel, padding: ViewStatePadding, ) -> Option<ViewRegion>

fn get_intersection_time( ray_origin: Vector3<f64>, ray_direction: Vector3<f64>, plane_origin: Vector3<f64>, plane_normal: Vector3<f64>, ) -> f64

fn furthest_distance( &self, camera_height: f64, center_offset: Point2<f64>, ) -> f64

pub fn camera_to_center_distance(&self) -> f64

pub fn view_projection(&self) -> ViewProjection

This function matches how maplibre-gl-js implements perspective and cameras at the time of the mapbox -> maplibre fork: src/geo/transform.ts#L680

pub fn zoom(&self) -> Zoom

pub fn did_zoom_change(&self) -> bool

pub fn update_zoom(&mut self, new_zoom: Zoom)

pub fn camera(&self) -> &Camera

pub fn camera_mut(&mut self) -> &mut Camera

pub fn did_camera_change(&self) -> bool

pub fn update_references(&mut self)

pub(crate) fn clip_to_window_transform(&self) -> Matrix4<f64>

A transform which can be used to transform between clip and window space. Adopted from here (Direct3D).

pub(crate) fn clip_to_window(&self, clip: &Vector4<f64>) -> Vector4<f64>

Transforms coordinates in clip space to window coordinates.

Adopted from here (Direct3D).

pub(crate) fn clip_to_window_maplibre( &self, clip: &Vector4<f64>, ) -> Vector4<f64>

The way how maplibre converts from clip to window space: https://github.com/maplibre/maplibre-native/blob/4add9ead08799577a37c465b8cb1266676b6c41e/src/mbgl/text/collision_index.cpp/#L437-L438

fn clip_to_window_vulkan(&self, clip: &Vector4<f64>) -> Vector3<f64>

Alternative implementation to clip_to_window. Transforms coordinates in clip space to window coordinates.

Adopted from here and here (Vulkan).

fn window_to_world( &self, window: &Vector3<f64>, inverted_view_proj: &InvertedViewProjection, ) -> Vector3<f64>

Order of transformations reversed: https://computergraphics.stackexchange.com/questions/6087/screen-space-coordinates-to-eye-space-conversion/6093 w is lost.

OpenGL explanation: https://www.khronos.org/opengl/wiki/Compute_eye_space_from_window_space#From_window_to_ndc

fn window_to_world_nalgebra( window: &Vector3<f64>, inverted_view_proj: &InvertedViewProjection, width: f64, height: f64, ) -> Vector3<f64>

Alternative implementation to window_to_world

Adopted from here.

pub fn window_to_world_at_ground( &self, window: &Vector2<f64>, inverted_view_proj: &InvertedViewProjection, bound: bool, ) -> Option<Vector2<f64>>

Gets the world coordinates for the specified window coordinates on the z=0 plane.

pub fn view_region_bounding_box( &self, inverted_view_proj: &InvertedViewProjection, ) -> Option<Aabb2<f64>>

Calculates an Aabb2 bounding box which contains at least the visible area on the z=0 plane. One can think of it as being the bounding box of the geometry which forms the intersection between the viewing frustum and the z=0 plane.

This implementation works in the world 3D space. It casts rays from the corners of the window to calculate intersections points with the z=0 plane. Then a bounding box is calculated.

Note: It is possible that no such bounding box exists. This is the case if the z=0 plane is not in view.

pub fn view_region_bounding_box_ndc(&self) -> Option<Aabb2<f64>>

An alternative implementation for view_region_bounding_box.

This implementation works in the NDC space. We are creating a plane in the world 3D space. Then we are transforming it to the NDC space. In NDC space it is easy to calculate the intersection points between an Aabb3 and a plane. The resulting Aabb2 is returned.

pub fn height(&self) -> f64

pub fn width(&self) -> f64