Trait IntoSystem

pub trait IntoSystem: Sized {
    type System: System;

    // Required method
    fn into_system(self) -> Self::System;
}
Conversion trait to turn something into a System.

Use this to get a system from a function. Also note that every system implements this trait as well.

Required Associated Types

Required Methods

fn into_system(self) -> Self::System

Turns this value into its corresponding System.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<F> IntoSystem for F
where F: FnMut(&mut MapContext) -> SystemResult + 'static,