Function tile_coordinates_bavaria

pub fn tile_coordinates_bavaria(grid: &Grid, zoom: u8) -> Vec<(u8, u32, u32)>
Returns coordinates for tiles within bavaria according to the specified grid. The grid is responsible for defining the coordinate system. For example whether Slippy map tilenames (also known as XYZ) or TMS is used.

Additional Resources:

  • https://www.maptiler.com/google-maps-coordinates-tile-bounds-projection
  • https://gist.github.com/maptiler/fddb5ce33ba995d5523de9afdf8ef118